@@ -1,15 +1,18 @@
 const webpack = require('webpack');
 const merge = require('webpack-merge');
 const baseConfig = require('./webpack.config.js');
-const UglifyJsPlugin = require('uglifyjs-webpack-plugin')
+const TerserPlugin = require('terser-webpack-plugin');
 
 
 module.exports = merge(baseConfig, {
   mode: 'production',
+  devtool: '#source-map',
   optimization: {
+    minimize: true,
     minimizer: [
-      new UglifyJsPlugin({
-        test: /(vendor\.js)+/i
-      })
-    ]
-  }});
+      new TerserPlugin({
+        test: /vendor\.js(\?.*)?$/i,
+      }),
+    ],
+  },
+});
