@@ -3,25 +3,39 @@ OC.L10N.register(
     {
     "Hours" : "Часове",
     "Minutes" : "Минути",
+    "File already exists" : "Файлът вече съществува",
+    "Personal" : "Лични",
     "Finished" : "Готово",
     "To review" : "За преглед",
     "Action needed" : "Необходимо е действие",
     "Later" : "По-късно",
+    "Done" : "Готово",
     "The file was uploaded" : "Файлът е качен",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на файла надвишава максималния размер определен от MAX_FILE_SIZE в HTML формата.",
     "The file was only partially uploaded" : "Файлът е качен частично",
     "No file was uploaded" : "Нито един файл не е качен",
+    "Missing a temporary folder" : "Липсва временна папка",
+    "Submit" : "Изпращане",
+    "Actions" : "Действия",
+    "Close" : "Затваряне",
     "Sharing" : "Споделяне",
     "Tags" : "Етикети",
     "Select users or groups to share with" : "Споделяне с потребители или групи",
+    "Group" : "Група",
+    "Circle" : "Кръг",
     "No matching user or group found." : "Не са намерени съвпадащи потребители или групи",
     "Loading" : "Зареждане",
     "Edit" : "Редакция",
     "Share" : "Сподели",
     "Manage" : "Управление",
     "Discard share" : "Отхвърляне на споделяне",
+    "Delete tag" : "Изтрий таг",
     "Create" : "Създай",
+    "Create a new tag" : "Създаване на нов етикет",
+    "Status" : "Състояние",
     "Title" : "Име",
     "Members" : "Членове",
+    "More actions" : "Още действия",
     "Cancel upload" : "Откажи качването",
     "by" : "от",
     "Modified:" : "Променена:",
