@@ -67,9 +67,9 @@ OC.L10N.register(
     "You have added the attachment {attachment} to card {card}" : "添付ファイル{attachment}をカード{card}に追加しました",
     "{user} has added the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に追加しました",
     "You have updated the attachment {attachment} on card {card}" : "カード{card}の添付ファイル{attachment}を更新しました",
-    "{user} has updated the attachment {attachment} to card {card}" : "{user}がカード {card}の添付ファイル {attachment}を更新しました",
+    "{user} has updated the attachment {attachment} on card {card}" : "{user}がカード{card}の添付ファイル{attachment}を更新しました",
     "You have deleted the attachment {attachment} from card {card}" : "カード{card}から添付ファイル{attachment}を削除しました",
-    "{user} has deleted the attachment {attachment} to card {card}" : "{user}がカード{card}の添付ファイル{attachment}を削除しました",
+    "{user} has deleted the attachment {attachment} from card {card}" : "{user}がカード{card}から添付ファイル{attachment}を削除しました",
     "You have restored the attachment {attachment} to card {card}" : "添付ファイル{attachment}をカード{card}に復元しました",
     "{user} has restored the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に復元しました",
     "You have commented on card {card}" : "カード{card}にコメントしました",
