@@ -2,25 +2,39 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "Ажлын талбар",
+    "Personal" : "Хувийн",
     "Finished" : "Дуусгасан",
     "To review" : "Дахин хянах",
     "Action needed" : "Үйлдэл шаардлагатай",
     "Later" : "Хойшлуулах",
+    "Done" : "Хийсэн",
+    "Submit" : "мэдэгдэх",
     "Show archived cards" : "Архивлагдсан картуудыг харах",
     "Hide archived cards" : "Архивлагдсан картуудыг нуух",
+    "Actions" : "Үйл ажиллагаа",
     "Enter a card title" : "Картын нэр оруулах",
+    "Close" : "Хаах",
     "Sharing" : "Түгээх",
+    "Tags" : "Tag-үүд",
     "Select users or groups to share with" : "Түгээх хэрэглэгч, бүлэг сонгоно уу",
+    "Group" : "Бүлэг",
+    "Circle" : "Тойрог",
     "No matching user or group found." : "Тохирох бүлэг эсвэл хэрэглэгч олдохгүй байна.",
+    "Loading" : "Loading",
     "Edit" : "Засварлах",
     "Share" : "Түгээх",
     "Manage" : "Зохицуулах",
     "Discard share" : "Түгээлтийг хүчингүй болгох",
+    "Create" : "Үүсгэх",
+    "Status" : "төлөв",
+    "Title" : "Цол/Албан тушаал",
     "Members" : "Гишүүд",
     "Modified:" : "Өөрчлөгдсөн:",
     "Created:" : "Үүсгэсэн:",
     "Description" : "Тайлбар",
+    "Attachments" : "Хавсралт",
     "Saved" : "Хадгалсан",
-    "Add a card description…" : "Картын тайлбар..."
+    "Add a card description…" : "Картын тайлбар...",
+    "Settings" : "Тохиргоо"
 },
 "nplurals=2; plural=(n != 1);");
