@@ -11,6 +11,7 @@ OC.L10N.register(
     "Minutes" : "Minút",
     "Link to a board" : "Odkaz na nástenku",
     "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}",
+    "File already exists" : "Súbor už existuje",
     "You have created a new board {board}" : "Vytvorili ste nová nástenku {board}",
     "{user} has created a new board {board}" : "Používateľ {user} vytvoril novú nástenku {board}",
     "You have deleted the board {board}" : "Vymazali ste nástenku {board}",
@@ -18,6 +19,7 @@ OC.L10N.register(
     "You have restored the board {board}" : "Obnovili ste nástenku {board}",
     "{user} has restored the board {board}" : "Používateľ {user} obnovil nástenku {board}",
     "You have shared the board {board} with {acl}" : "Sprístupnili ste nástenku {board} s {acl}",
+    "{user} has shared the board {board} with {acl}" : "Používateľ {user} sprístupnil nástenku {board} pre {acl}",
     "You have removed {acl} from the board {board}" : "Odobrali ste {acl} z nástenky {board}",
     "{user} has removed {acl} from the board {board}" : "Používateľ {user} odobral {acl} z nástenky {board}",
     "You have renamed the board {before} to {board}" : "Premenovali ste nástenku {before} na {board}",
@@ -65,9 +67,9 @@ OC.L10N.register(
     "You have added the attachment {attachment} to card {card}" : "Pridali ste prílohu {attachment} ku karte {card}",
     "{user} has added the attachment {attachment} to card {card}" : "Používateľ {user} pridal prílohu {attachment} ku karte {card}",
     "You have updated the attachment {attachment} on card {card}" : "Aktualizovali ste prílohu {attachment} na karte {card}",
-    "{user} has updated the attachment {attachment} to card {card}" : "Používateľ {user} aktualizoval prílohu {attachment} ku karte {card}",
+    "{user} has updated the attachment {attachment} on card {card}" : "Používateľ {user} aktualizoval prílohu {attachment} na karte {card}",
     "You have deleted the attachment {attachment} from card {card}" : "Vymazali ste prílohu {attachment} na karte {card}",
-    "{user} has deleted the attachment {attachment} to card {card}" : "Používateľ {user} vymazal prílohu {attachment} z karty {card}",
+    "{user} has deleted the attachment {attachment} from card {card}" : "Používateľ {user} vymazal prílohu {attachment} na karte {card}",
     "You have restored the attachment {attachment} to card {card}" : "Obnovili ste prílohu {attachment} na karte {card}",
     "{user} has restored the attachment {attachment} to card {card}" : "Používateľ {user} obnovil prílohu {attachment} na karte {card}",
     "You have commented on card {card}" : "Komentovali ste kartu {card}",
@@ -75,6 +77,7 @@ OC.L10N.register(
     "A <strong>card description</strong> inside the Deck app has been changed" : "V apke Nástenka sa zmenil <strong>Popis karty</strong>",
     "Deck" : "Nástenka",
     "Changes in the <strong>Deck app</strong>" : "Zmeny v apke <strong>Nástenka</strong>",
+    "A <strong>comment</strong> was created on a card" : "Na karte bol vytvorený <strong>komentár</strong>. ",
     "Personal" : "Osobné",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Používateľ %s vám priradil kartu „%s“ na „%s“.",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "Používateľ {user} vám priradil kartu „%s“ na „%s“.",
