@@ -67,9 +67,9 @@ OC.L10N.register(
     "You have added the attachment {attachment} to card {card}" : "Du har lagt till bilagan {attachment} till kortet {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} har lagt till bilagan {attachment} till kortet {card}",
     "You have updated the attachment {attachment} on card {card}" : "Du har uppdaterat bilagan {attachment} på kortet {card}",
-    "{user} has updated the attachment {attachment} to card {card}" : "{user} har uppdaterat bilagan {attachment} på kortet {card}",
+    "{user} has updated the attachment {attachment} on card {card}" : "{user} har uppdaterat bilagan {attachment} på kortet {card}",
     "You have deleted the attachment {attachment} from card {card}" : "Du har raderat bilagan {attachment} från kortet {card}",
-    "{user} has deleted the attachment {attachment} to card {card}" : "{user} har raderat bilagan {attachment} från kortet {card}",
+    "{user} has deleted the attachment {attachment} from card {card}" : "{user} har raderat bilagan {attachment} från kortet {card}",
     "You have restored the attachment {attachment} to card {card}" : "Du har återställt bilagan {attachment} till kortet {card}",
     "{user} has restored the attachment {attachment} to card {card}" : "{user} har återställt bilagan {attachment} till kortet {card}",
     "You have commented on card {card}" : "Du har kommenterat på kortet {card}",
