@@ -98,6 +98,15 @@ class BoardService {
 		$this->userId = $userId;
 	}
 
+	/**
+	 * Set a different user than the current one, e.g. when no user is available in occ
+	 *
+	 * @param string $userId
+	 */
+	public function setUserId(string $userId): void {
+		$this->userId = $userId;
+	}
+
 	/**
 	 * @return array
 	 */
